@@ -7,17 +7,15 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/AlecAivazis/survey/v2"
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/git"
 	"github.com/cli/cli/v2/internal/ghinstance"
-	"github.com/cli/cli/v2/internal/run"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/google/shlex"
 )
 
 type GitCredentialFlow struct {
 	Executable string
+	Prompter   Prompt
 
 	shouldSetup bool
 	helper      string
@@ -32,13 +30,12 @@ func (flow *GitCredentialFlow) Prompt(hostname string) error {
 		return nil
 	}
 
-	err := prompt.SurveyAskOne(&survey.Confirm{
-		Message: "Authenticate Git with your GitHub credentials?",
-		Default: true,
-	}, &flow.shouldSetup)
+	result, err := flow.Prompter.Confirm("Authenticate Git with your GitHub credentials?", true)
 	if err != nil {
-		return fmt.Errorf("could not prompt: %w", err)
+		return err
 	}
+	flow.shouldSetup = result
+
 	if flow.shouldSetup {
 		if isGitMissing(gitErr) {
 			return gitErr
@@ -84,7 +81,7 @@ func (flow *GitCredentialFlow) gitCredentialSetup(hostname, username, password s
 				configErr = err
 				break
 			}
-			if err = run.PrepareCmd(preConfigureCmd).Run(); err != nil {
+			if err = preConfigureCmd.Run(); err != nil {
 				configErr = err
 				break
 			}
@@ -98,7 +95,7 @@ func (flow *GitCredentialFlow) gitCredentialSetup(hostname, username, password s
 			if err != nil {
 				configErr = err
 			} else {
-				configErr = run.PrepareCmd(configureCmd).Run()
+				configErr = configureCmd.Run()
 			}
 		}
 
@@ -116,7 +113,7 @@ func (flow *GitCredentialFlow) gitCredentialSetup(hostname, username, password s
 		host=%s
 	`, hostname))
 
-	err = run.PrepareCmd(rejectCmd).Run()
+	err = rejectCmd.Run()
 	if err != nil {
 		return err
 	}
@@ -133,7 +130,7 @@ func (flow *GitCredentialFlow) gitCredentialSetup(hostname, username, password s
 		password=%s
 	`, hostname, username, password))
 
-	err = run.PrepareCmd(approveCmd).Run()
+	err = approveCmd.Run()
 	if err != nil {
 		return err
 	}
