@@ -13,6 +13,7 @@ import (
 
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/AlecAivazis/survey/v2/terminal"
+	"github.com/cli/cli/v2/internal/browser"
 	"github.com/cli/cli/v2/internal/codespaces"
 	"github.com/cli/cli/v2/internal/codespaces/api"
 	"github.com/cli/cli/v2/pkg/iostreams"
@@ -22,10 +23,6 @@ import (
 	"golang.org/x/term"
 )
 
-type browser interface {
-	Browse(string) error
-}
-
 type executable interface {
 	Executable() string
 }
@@ -35,10 +32,10 @@ type App struct {
 	apiClient  apiClient
 	errLogger  *log.Logger
 	executable executable
-	browser    browser
+	browser    browser.Browser
 }
 
-func NewApp(io *iostreams.IOStreams, exe executable, apiClient apiClient, browser browser) *App {
+func NewApp(io *iostreams.IOStreams, exe executable, apiClient apiClient, browser browser.Browser) *App {
 	errLogger := log.New(io.ErrOut, "", 0)
 
 	return &App{
@@ -69,17 +66,11 @@ type liveshareSession interface {
 	StartSharing(context.Context, string, int) (liveshare.ChannelID, error)
 	StartSSHServer(context.Context) (int, string, error)
 	StartSSHServerWithOptions(context.Context, liveshare.StartSSHServerOptions) (int, string, error)
+	RebuildContainer(context.Context) error
 }
 
 // Connects to a codespace using Live Share and returns that session
 func startLiveShareSession(ctx context.Context, codespace *api.Codespace, a *App, debug bool, debugFile string) (session liveshareSession, err error) {
-	// While connecting, ensure in the background that the user has keys installed.
-	// That lets us report a more useful error message if they don't.
-	authkeys := make(chan error, 1)
-	go func() {
-		authkeys <- checkAuthorizedKeys(ctx, a.apiClient)
-	}()
-
 	liveshareLogger := noopLogger()
 	if debug {
 		debugLogger, err := newFileLogger(debugFile)
@@ -94,9 +85,6 @@ func startLiveShareSession(ctx context.Context, codespace *api.Codespace, a *App
 
 	session, err = codespaces.ConnectToLiveshare(ctx, a, liveshareLogger, a.apiClient, codespace)
 	if err != nil {
-		if authErr := <-authkeys; authErr != nil {
-			return nil, fmt.Errorf("failed to fetch authorization keys: %w", authErr)
-		}
 		return nil, fmt.Errorf("failed to connect to Live Share: %w", err)
 	}
 
@@ -105,7 +93,6 @@ func startLiveShareSession(ctx context.Context, codespace *api.Codespace, a *App
 
 //go:generate moq -fmt goimports -rm -skip-ensure -out mock_api.go . apiClient
 type apiClient interface {
-	GetUser(ctx context.Context) (*api.User, error)
 	GetCodespace(ctx context.Context, name string, includeConnection bool) (*api.Codespace, error)
 	GetOrgMemberCodespace(ctx context.Context, orgName string, userName string, codespaceName string) (*api.Codespace, error)
 	ListCodespaces(ctx context.Context, opts api.ListCodespacesOptions) ([]*api.Codespace, error)
@@ -115,8 +102,7 @@ type apiClient interface {
 	CreateCodespace(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error)
 	EditCodespace(ctx context.Context, codespaceName string, params *api.EditCodespaceParams) (*api.Codespace, error)
 	GetRepository(ctx context.Context, nwo string) (*api.Repository, error)
-	AuthorizedKeys(ctx context.Context, user string) ([]byte, error)
-	GetCodespacesMachines(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error)
+	GetCodespacesMachines(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error)
 	GetCodespaceRepositoryContents(ctx context.Context, codespace *api.Codespace, path string) ([]byte, error)
 	ListDevContainers(ctx context.Context, repoID int, branch string, limit int) (devcontainers []api.DevContainerEntry, err error)
 	GetCodespaceRepoSuggestions(ctx context.Context, partialSearch string, params api.RepoSearchParameters) ([]string, error)
@@ -240,25 +226,6 @@ func ask(qs []*survey.Question, response interface{}) error {
 	return err
 }
 
-// checkAuthorizedKeys reports an error if the user has not registered any SSH keys;
-// see https://github.com/cli/cli/v2/issues/166#issuecomment-921769703.
-// The check is not required for security but it improves the error message.
-func checkAuthorizedKeys(ctx context.Context, client apiClient) error {
-	user, err := client.GetUser(ctx)
-	if err != nil {
-		return fmt.Errorf("error getting user: %w", err)
-	}
-
-	keys, err := client.AuthorizedKeys(ctx, user.Login)
-	if err != nil {
-		return fmt.Errorf("failed to read GitHub-authorized SSH keys for %s: %w", user, err)
-	}
-	if len(keys) == 0 {
-		return fmt.Errorf("user %s has no GitHub-authorized SSH keys", user)
-	}
-	return nil // success
-}
-
 var ErrTooManyArgs = errors.New("the command accepts no arguments")
 
 func noArgsConstraint(cmd *cobra.Command, args []string) error {
