@@ -45,7 +45,7 @@ func TestApp_Create(t *testing.T) {
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error) {
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						return []*api.Machine{
 							{
 								Name:        "GIGA",
@@ -99,7 +99,7 @@ func TestApp_Create(t *testing.T) {
 							Type:  "User",
 						}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error) {
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						return []*api.Machine{
 							{
 								Name:        "GIGA",
@@ -136,6 +136,77 @@ func TestApp_Create(t *testing.T) {
 			},
 			wantStdout: "monalisa-dotfiles-abcd1234\n",
 		},
+		{
+			name: "create codespace with devcontainer path results in selecting the correct machine type",
+			fields: fields{
+				apiClient: &apiClientMock{
+					GetRepositoryFunc: func(ctx context.Context, nwo string) (*api.Repository, error) {
+						return &api.Repository{
+							ID:            1234,
+							FullName:      nwo,
+							DefaultBranch: "main",
+						}, nil
+					},
+					GetCodespaceBillableOwnerFunc: func(ctx context.Context, nwo string) (*api.User, error) {
+						return &api.User{
+							Login: "monalisa",
+							Type:  "User",
+						}, nil
+					},
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
+						if devcontainerPath == "" {
+							return []*api.Machine{
+								{
+									Name:        "GIGA",
+									DisplayName: "Gigabits of a machine",
+								},
+							}, nil
+						} else {
+							return []*api.Machine{
+								{
+									Name:        "MEGA",
+									DisplayName: "Megabits of a machine",
+								},
+								{
+									Name:        "GIGA",
+									DisplayName: "Gigabits of a machine",
+								},
+							}, nil
+						}
+					},
+					CreateCodespaceFunc: func(ctx context.Context, params *api.CreateCodespaceParams) (*api.Codespace, error) {
+						if params.Branch != "main" {
+							return nil, fmt.Errorf("got branch %q, want %q", params.Branch, "main")
+						}
+						if params.IdleTimeoutMinutes != 30 {
+							return nil, fmt.Errorf("idle timeout minutes was %v", params.IdleTimeoutMinutes)
+						}
+						if params.RetentionPeriodMinutes != nil {
+							return nil, fmt.Errorf("retention period minutes expected nil, was %v", params.RetentionPeriodMinutes)
+						}
+						if params.DevContainerPath != ".devcontainer/foobar/devcontainer.json" {
+							return nil, fmt.Errorf("got dev container path %q, want %q", params.DevContainerPath, ".devcontainer/foobar/devcontainer.json")
+						}
+						return &api.Codespace{
+							Name: "monalisa-dotfiles-abcd1234",
+							Machine: api.CodespaceMachine{
+								Name:        "MEGA",
+								DisplayName: "Megabits of a machine",
+							},
+						}, nil
+					},
+				},
+			},
+			opts: createOptions{
+				repo:             "monalisa/dotfiles",
+				branch:           "",
+				machine:          "MEGA",
+				showStatus:       false,
+				idleTimeout:      30 * time.Minute,
+				devContainerPath: ".devcontainer/foobar/devcontainer.json",
+			},
+			wantStdout: "monalisa-dotfiles-abcd1234\n",
+		},
 		{
 			name: "create codespace with default branch with default devcontainer if no path provided and no devcontainer files exist in the repo",
 			fields: fields{
@@ -156,7 +227,7 @@ func TestApp_Create(t *testing.T) {
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return []api.DevContainerEntry{}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error) {
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						return []*api.Machine{
 							{
 								Name:        "GIGA",
@@ -246,7 +317,7 @@ func TestApp_Create(t *testing.T) {
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return []api.DevContainerEntry{}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error) {
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						return []*api.Machine{
 							{
 								Name:        "GIGA",
@@ -302,7 +373,7 @@ func TestApp_Create(t *testing.T) {
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error) {
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						return []*api.Machine{
 							{
 								Name:        "GIGA",
@@ -384,7 +455,7 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error) {
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						return []*api.Machine{
 							{
 								Name:        "GIGA",
@@ -406,7 +477,8 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 				showStatus:  false,
 				idleTimeout: 30 * time.Minute,
 			},
-			wantStdout: "  ✓ Codespaces usage for this repository is paid for by megacorp\nmegacorp-private-abcd1234\n",
+			wantStderr: "  ✓ Codespaces usage for this repository is paid for by megacorp\n",
+			wantStdout: "megacorp-private-abcd1234\n",
 		},
 		{
 			name: "doesn't mention billable owner when it's the individual",
@@ -428,7 +500,7 @@ Alternatively, you can run "create" with the "--default-permissions" option to c
 					ListDevContainersFunc: func(ctx context.Context, repoID int, branch string, limit int) ([]api.DevContainerEntry, error) {
 						return []api.DevContainerEntry{{Path: ".devcontainer/devcontainer.json"}}, nil
 					},
-					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string) ([]*api.Machine, error) {
+					GetCodespacesMachinesFunc: func(ctx context.Context, repoID int, branch, location string, devcontainerPath string) ([]*api.Machine, error) {
 						return []*api.Machine{
 							{
 								Name:        "GIGA",
@@ -490,16 +562,6 @@ func TestBuildDisplayName(t *testing.T) {
 		prebuildAvailability string
 		expectedDisplayName  string
 	}{
-		{
-			name:                 "prebuild availability is pool",
-			prebuildAvailability: "pool",
-			expectedDisplayName:  "4 cores, 8 GB RAM, 32 GB storage (Prebuild ready)",
-		},
-		{
-			name:                 "prebuild availability is blob",
-			prebuildAvailability: "blob",
-			expectedDisplayName:  "4 cores, 8 GB RAM, 32 GB storage (Prebuild ready)",
-		},
 		{
 			name:                 "prebuild availability is none",
 			prebuildAvailability: "none",
