@@ -339,7 +339,15 @@ type binManifest struct {
 func (m *Manager) Install(repo ghrepo.Interface, target string) error {
 	isBin, err := isBinExtension(m.client, repo)
 	if err != nil {
-		return fmt.Errorf("could not check for binary extension: %w", err)
+		if errors.Is(err, releaseNotFoundErr) {
+			if ok, err := repoExists(m.client, repo); err != nil {
+				return err
+			} else if !ok {
+				return repositoryNotFoundErr
+			}
+		} else {
+			return fmt.Errorf("could not check for binary extension: %w", err)
+		}
 	}
 	if isBin {
 		return m.installBin(repo, target)
@@ -760,11 +768,6 @@ func isBinExtension(client *http.Client, repo ghrepo.Interface) (isBin bool, err
 	var r *release
 	r, err = fetchLatestRelease(client, repo)
 	if err != nil {
-		httpErr, ok := err.(api.HTTPError)
-		if ok && httpErr.StatusCode == 404 {
-			err = nil
-			return
-		}
 		return
 	}
 
