@@ -10,8 +10,10 @@ import (
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/context"
 	"github.com/cli/cli/v2/git"
+	"github.com/cli/cli/v2/internal/browser"
 	"github.com/cli/cli/v2/internal/config"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	"github.com/cli/cli/v2/internal/prompter"
 	"github.com/cli/cli/v2/pkg/cmd/extension"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
@@ -31,7 +33,9 @@ func New(appVersion string) *cmdutil.Factory {
 	f.HttpClient = httpClientFunc(f, appVersion) // Depends on Config, IOStreams, and appVersion
 	f.Remotes = remotesFunc(f)                   // Depends on Config
 	f.BaseRepo = BaseRepoFunc(f)                 // Depends on Remotes
-	f.Browser = browser(f)                       // Depends on Config, and IOStreams
+	f.Prompter = newPrompter(f)                  // Depends on Config and IOStreams
+	f.Browser = newBrowser(f)                    // Depends on Config, and IOStreams
+	f.GitClient = newGitClient(f)                // Depends on IOStreams, and Executable
 	f.ExtensionManager = extensionManager(f)     // Depends on Config, HttpClient, and IOStreams
 
 	return f
@@ -64,7 +68,7 @@ func SmartBaseRepoFunc(f *cmdutil.Factory) func() (ghrepo.Interface, error) {
 		if err != nil {
 			return nil, err
 		}
-		baseRepo, err := repoContext.BaseRepo(f.IOStreams)
+		baseRepo, err := repoContext.BaseRepo(f.IOStreams, f.Prompter)
 		if err != nil {
 			return nil, err
 		}
@@ -103,28 +107,27 @@ func httpClientFunc(f *cmdutil.Factory, appVersion string) func() (*http.Client,
 	}
 }
 
-func browser(f *cmdutil.Factory) cmdutil.Browser {
+func newGitClient(f *cmdutil.Factory) *git.Client {
 	io := f.IOStreams
-	return cmdutil.NewBrowser(browserLauncher(f), io.Out, io.ErrOut)
+	ghPath := f.Executable()
+	client := &git.Client{
+		GhPath: ghPath,
+		Stderr: io.ErrOut,
+		Stdin:  io.In,
+		Stdout: io.Out,
+	}
+	return client
 }
 
-// Browser precedence
-// 1. GH_BROWSER
-// 2. browser from config
-// 3. BROWSER
-func browserLauncher(f *cmdutil.Factory) string {
-	if ghBrowser := os.Getenv("GH_BROWSER"); ghBrowser != "" {
-		return ghBrowser
-	}
+func newBrowser(f *cmdutil.Factory) browser.Browser {
+	io := f.IOStreams
+	return browser.New("", io.Out, io.ErrOut)
+}
 
-	cfg, err := f.Config()
-	if err == nil {
-		if cfgBrowser, _ := cfg.Get("", "browser"); cfgBrowser != "" {
-			return cfgBrowser
-		}
-	}
-
-	return os.Getenv("BROWSER")
+func newPrompter(f *cmdutil.Factory) prompter.Prompter {
+	editor, _ := cmdutil.DetermineEditor(f.Config)
+	io := f.IOStreams
+	return prompter.New(editor, io.In, io.Out, io.ErrOut)
 }
 
 func configFunc() func() (config.Config, error) {
@@ -175,7 +178,9 @@ func ioStreams(f *cmdutil.Factory) *iostreams.IOStreams {
 		return io
 	}
 
-	if prompt, _ := cfg.GetOrDefault("", "prompt"); prompt == "disabled" {
+	if _, ghPromptDisabled := os.LookupEnv("GH_PROMPT_DISABLED"); ghPromptDisabled {
+		io.SetNeverPrompt(true)
+	} else if prompt, _ := cfg.GetOrDefault("", "prompt"); prompt == "disabled" {
 		io.SetNeverPrompt(true)
 	}
 
