@@ -8,6 +8,8 @@ import (
 	"path/filepath"
 	"testing"
 
+	"github.com/cli/cli/v2/api"
+	"github.com/cli/cli/v2/internal/browser"
 	"github.com/cli/cli/v2/internal/ghrepo"
 	"github.com/cli/cli/v2/pkg/cmd/pr/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
@@ -152,7 +154,7 @@ func TestNewCmdComment(t *testing.T) {
 
 			f := &cmdutil.Factory{
 				IOStreams: ios,
-				Browser:   &cmdutil.TestBrowser{},
+				Browser:   &browser.Stub{},
 			}
 
 			argv, err := shlex.Split(tt.input)
@@ -199,7 +201,7 @@ func Test_commentRun(t *testing.T) {
 				InputType:   0,
 				Body:        "",
 
-				InteractiveEditSurvey: func() (string, error) { return "comment body", nil },
+				InteractiveEditSurvey: func(string) (string, error) { return "comment body", nil },
 				ConfirmSubmitSurvey:   func() (bool, error) { return true, nil },
 			},
 			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
@@ -207,6 +209,22 @@ func Test_commentRun(t *testing.T) {
 			},
 			stdout: "https://github.com/OWNER/REPO/issues/123#issuecomment-456\n",
 		},
+		{
+			name: "interactive editor with edit last",
+			input: &shared.CommentableOptions{
+				Interactive: true,
+				InputType:   0,
+				Body:        "",
+				EditLast:    true,
+
+				InteractiveEditSurvey: func(string) (string, error) { return "comment body", nil },
+				ConfirmSubmitSurvey:   func() (bool, error) { return true, nil },
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockCommentUpdate(t, reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/issues/123#issuecomment-111\n",
+		},
 		{
 			name: "non-interactive web",
 			input: &shared.CommentableOptions{
@@ -218,6 +236,18 @@ func Test_commentRun(t *testing.T) {
 			},
 			stderr: "Opening github.com/OWNER/REPO/issues/123 in your browser.\n",
 		},
+		{
+			name: "non-interactive web with edit last",
+			input: &shared.CommentableOptions{
+				Interactive: false,
+				InputType:   shared.InputTypeWeb,
+				Body:        "",
+				EditLast:    true,
+
+				OpenInBrowser: func(string) error { return nil },
+			},
+			stderr: "Opening github.com/OWNER/REPO/issues/123 in your browser.\n",
+		},
 		{
 			name: "non-interactive editor",
 			input: &shared.CommentableOptions{
@@ -225,13 +255,28 @@ func Test_commentRun(t *testing.T) {
 				InputType:   shared.InputTypeEditor,
 				Body:        "",
 
-				EditSurvey: func() (string, error) { return "comment body", nil },
+				EditSurvey: func(string) (string, error) { return "comment body", nil },
 			},
 			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
 				mockCommentCreate(t, reg)
 			},
 			stdout: "https://github.com/OWNER/REPO/issues/123#issuecomment-456\n",
 		},
+		{
+			name: "non-interactive editor with edit last",
+			input: &shared.CommentableOptions{
+				Interactive: false,
+				InputType:   shared.InputTypeEditor,
+				Body:        "",
+				EditLast:    true,
+
+				EditSurvey: func(string) (string, error) { return "comment body", nil },
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockCommentUpdate(t, reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/issues/123#issuecomment-111\n",
+		},
 		{
 			name: "non-interactive inline",
 			input: &shared.CommentableOptions{
@@ -244,6 +289,19 @@ func Test_commentRun(t *testing.T) {
 			},
 			stdout: "https://github.com/OWNER/REPO/issues/123#issuecomment-456\n",
 		},
+		{
+			name: "non-interactive inline with edit last",
+			input: &shared.CommentableOptions{
+				Interactive: false,
+				InputType:   shared.InputTypeInline,
+				Body:        "comment body",
+				EditLast:    true,
+			},
+			httpStubs: func(t *testing.T, reg *httpmock.Registry) {
+				mockCommentUpdate(t, reg)
+			},
+			stdout: "https://github.com/OWNER/REPO/issues/123#issuecomment-111\n",
+		},
 	}
 	for _, tt := range tests {
 		ios, _, stdout, stderr := iostreams.Test()
@@ -262,7 +320,14 @@ func Test_commentRun(t *testing.T) {
 			return &http.Client{Transport: reg}, nil
 		}
 		tt.input.RetrieveCommentable = func() (shared.Commentable, ghrepo.Interface, error) {
-			return &mockCommentable{}, ghrepo.New("OWNER", "REPO"), nil
+			return &api.Issue{
+				ID:  "ISSUE-ID",
+				URL: "https://github.com/OWNER/REPO/issues/123",
+				Comments: api.Comments{Nodes: []api.Comment{
+					{ID: "id1", Author: api.Author{Login: "octocat"}, URL: "https://github.com/OWNER/REPO/issues/123#issuecomment-111", ViewerDidAuthor: true},
+					{ID: "id2", Author: api.Author{Login: "monalisa"}, URL: "https://github.com/OWNER/REPO/issues/123#issuecomment-222"},
+				}},
+			}, ghrepo.New("OWNER", "REPO"), nil
 		}
 
 		t.Run(tt.name, func(t *testing.T) {
@@ -274,15 +339,6 @@ func Test_commentRun(t *testing.T) {
 	}
 }
 
-type mockCommentable struct{}
-
-func (c mockCommentable) Identifier() string {
-	return "ISSUE-ID"
-}
-func (c mockCommentable) Link() string {
-	return "https://github.com/OWNER/REPO/issues/123"
-}
-
 func mockCommentCreate(t *testing.T, reg *httpmock.Registry) {
 	reg.Register(
 		httpmock.GraphQL(`mutation CommentCreate\b`),
@@ -296,3 +352,17 @@ func mockCommentCreate(t *testing.T, reg *httpmock.Registry) {
 			}),
 	)
 }
+
+func mockCommentUpdate(t *testing.T, reg *httpmock.Registry) {
+	reg.Register(
+		httpmock.GraphQL(`mutation CommentUpdate\b`),
+		httpmock.GraphQLMutation(`
+		{ "data": { "updateIssueComment": { "issueComment": {
+			"url": "https://github.com/OWNER/REPO/issues/123#issuecomment-111"
+		} } } }`,
+			func(inputs map[string]interface{}) {
+				assert.Equal(t, "id1", inputs["id"])
+				assert.Equal(t, "comment body", inputs["body"])
+			}),
+	)
+}
