@@ -55,6 +55,7 @@ func Test_NewCmdMerge(t *testing.T) {
 				MergeStrategyEmpty:      true,
 				Body:                    "",
 				BodySet:                 false,
+				AuthorEmail:             "",
 			},
 		},
 		{
@@ -70,6 +71,7 @@ func Test_NewCmdMerge(t *testing.T) {
 				MergeStrategyEmpty:      true,
 				Body:                    "",
 				BodySet:                 false,
+				AuthorEmail:             "",
 			},
 		},
 		{
@@ -85,6 +87,7 @@ func Test_NewCmdMerge(t *testing.T) {
 				MergeStrategyEmpty:      true,
 				Body:                    "a body from file",
 				BodySet:                 true,
+				AuthorEmail:             "",
 			},
 		},
 		{
@@ -101,6 +104,7 @@ func Test_NewCmdMerge(t *testing.T) {
 				MergeStrategyEmpty:      true,
 				Body:                    "this is on standard input",
 				BodySet:                 true,
+				AuthorEmail:             "",
 			},
 		},
 		{
@@ -116,6 +120,40 @@ func Test_NewCmdMerge(t *testing.T) {
 				MergeStrategyEmpty:      true,
 				Body:                    "cool",
 				BodySet:                 true,
+				AuthorEmail:             "",
+			},
+		},
+		{
+			name:  "match-head-commit specified",
+			args:  "123 --match-head-commit 555",
+			isTTY: true,
+			want: MergeOptions{
+				SelectorArg:             "123",
+				DeleteBranch:            false,
+				IsDeleteBranchIndicated: false,
+				CanDeleteLocalBranch:    true,
+				MergeMethod:             PullRequestMergeMethodMerge,
+				MergeStrategyEmpty:      true,
+				Body:                    "",
+				BodySet:                 false,
+				MatchHeadCommit:         "555",
+				AuthorEmail:             "",
+			},
+		},
+		{
+			name:  "author email",
+			args:  "123 --author-email octocat@github.com",
+			isTTY: true,
+			want: MergeOptions{
+				SelectorArg:             "123",
+				DeleteBranch:            false,
+				IsDeleteBranchIndicated: false,
+				CanDeleteLocalBranch:    true,
+				MergeMethod:             PullRequestMergeMethodMerge,
+				MergeStrategyEmpty:      true,
+				Body:                    "",
+				BodySet:                 false,
+				AuthorEmail:             "octocat@github.com",
 			},
 		},
 		{
@@ -188,6 +226,8 @@ func Test_NewCmdMerge(t *testing.T) {
 			assert.Equal(t, tt.want.MergeStrategyEmpty, opts.MergeStrategyEmpty)
 			assert.Equal(t, tt.want.Body, opts.Body)
 			assert.Equal(t, tt.want.BodySet, opts.BodySet)
+			assert.Equal(t, tt.want.MatchHeadCommit, opts.MatchHeadCommit)
+			assert.Equal(t, tt.want.AuthorEmail, opts.AuthorEmail)
 		})
 	}
 }
@@ -479,6 +519,89 @@ func TestPrMerge_withRepoFlag(t *testing.T) {
 	}
 }
 
+func TestPrMerge_withMatchCommitHeadFlag(t *testing.T) {
+	http := initFakeHTTP()
+	defer http.Verify(t)
+
+	shared.RunCommandFinder(
+		"1",
+		&api.PullRequest{
+			ID:               "THE-ID",
+			Number:           1,
+			State:            "OPEN",
+			Title:            "The title of the PR",
+			MergeStateStatus: "CLEAN",
+		},
+		baseRepo("OWNER", "REPO", "main"),
+	)
+
+	http.Register(
+		httpmock.GraphQL(`mutation PullRequestMerge\b`),
+		httpmock.GraphQLMutation(`{}`, func(input map[string]interface{}) {
+			assert.Equal(t, 3, len(input))
+			assert.Equal(t, "THE-ID", input["pullRequestId"].(string))
+			assert.Equal(t, "MERGE", input["mergeMethod"].(string))
+			assert.Equal(t, "285ed5ab740f53ff6b0b4b629c59a9df23b9c6db", input["expectedHeadOid"].(string))
+		}))
+
+	cs, cmdTeardown := run.Stub()
+	defer cmdTeardown(t)
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
+	output, err := runCommand(http, "main", true, "pr merge 1 --merge --match-head-commit 285ed5ab740f53ff6b0b4b629c59a9df23b9c6db")
+	if err != nil {
+		t.Fatalf("error running command `pr merge`: %v", err)
+	}
+
+	r := regexp.MustCompile(`Merged pull request #1 \(The title of the PR\)`)
+
+	if !r.MatchString(output.Stderr()) {
+		t.Fatalf("output did not match regexp /%s/\n> output\n%q\n", r, output.Stderr())
+	}
+}
+
+func TestPrMerge_withAuthorFlag(t *testing.T) {
+	http := initFakeHTTP()
+	defer http.Verify(t)
+
+	shared.RunCommandFinder(
+		"1",
+		&api.PullRequest{
+			ID:               "THE-ID",
+			Number:           1,
+			State:            "OPEN",
+			Title:            "The title of the PR",
+			MergeStateStatus: "CLEAN",
+		},
+		baseRepo("OWNER", "REPO", "main"),
+	)
+
+	http.Register(
+		httpmock.GraphQL(`mutation PullRequestMerge\b`),
+		httpmock.GraphQLMutation(`{}`, func(input map[string]interface{}) {
+			assert.Equal(t, "THE-ID", input["pullRequestId"].(string))
+			assert.Equal(t, "MERGE", input["mergeMethod"].(string))
+			assert.Equal(t, "octocat@github.com", input["authorEmail"].(string))
+			assert.NotContains(t, input, "commitHeadline")
+		}),
+	)
+
+	cs, cmdTeardown := run.Stub()
+	defer cmdTeardown(t)
+	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
+
+	output, err := runCommand(http, "main", true, "pr merge 1 --merge --author-email octocat@github.com")
+	if err != nil {
+		t.Fatalf("error running command `pr merge`: %v", err)
+	}
+
+	r := regexp.MustCompile(`Merged pull request #1 \(The title of the PR\)`)
+
+	if !r.MatchString(output.Stderr()) {
+		t.Fatalf("output did not match regexp /%s/\n> output\n%q\n", r, output.Stderr())
+	}
+}
+
 func TestPrMerge_deleteBranch(t *testing.T) {
 	http := initFakeHTTP()
 	defer http.Verify(t)
@@ -902,6 +1025,7 @@ func TestPrMerge_alreadyMerged(t *testing.T) {
 	cs.Register(`git branch -D blueberries`, 0, "")
 	cs.Register(`git pull --ff-only`, 0, "")
 
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("Pull request #4 was already merged. Delete the branch locally?").AnswerWith(true)
 
@@ -963,6 +1087,7 @@ func TestPrMerge_alreadyMerged_withMergeStrategy_TTY(t *testing.T) {
 	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
 	cs.Register(`git branch -D `, 0, "")
 
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("Pull request #4 was already merged. Delete the branch locally?").AnswerWith(true)
 
@@ -1042,6 +1167,7 @@ func TestPRMergeTTY(t *testing.T) {
 
 	cs.Register(`git rev-parse --verify refs/heads/blueberries`, 0, "")
 
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("What merge method would you like to use?").AnswerDefault()
 	as.StubPrompt("Delete the branch locally and on GitHub?").AnswerDefault()
@@ -1103,6 +1229,7 @@ func TestPRMergeTTY_withDeleteBranch(t *testing.T) {
 	cs.Register(`git branch -D blueberries`, 0, "")
 	cs.Register(`git pull --ff-only`, 0, "")
 
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("What merge method would you like to use?").AnswerDefault()
 	as.StubPrompt("What's next?").AnswerWith("Submit")
@@ -1162,6 +1289,7 @@ func TestPRMergeTTY_squashEditCommitMsgAndSubject(t *testing.T) {
 	_, cmdTeardown := run.Stub()
 	defer cmdTeardown(t)
 
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("What merge method would you like to use?").AnswerWith("Squash and merge")
 	as.StubPrompt("Delete the branch on GitHub?").AnswerDefault()
@@ -1240,6 +1368,7 @@ func TestPRTTY_cancelled(t *testing.T) {
 
 	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
 
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("What merge method would you like to use?").AnswerDefault()
 	as.StubPrompt("Delete the branch locally and on GitHub?").AnswerDefault()
@@ -1259,6 +1388,7 @@ func Test_mergeMethodSurvey(t *testing.T) {
 		RebaseMergeAllowed: true,
 		SquashMergeAllowed: true,
 	}
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("What merge method would you like to use?").AnswerWith("Rebase and merge")
 
@@ -1566,6 +1696,7 @@ func TestPrAddToMergeQueueAdmin(t *testing.T) {
 	defer cmdTeardown(t)
 	cs.Register(`git rev-parse --verify refs/heads/`, 0, "")
 
+	//nolint:staticcheck // SA1019: prompt.NewAskStubber is deprecated: use PrompterMock
 	as := prompt.NewAskStubber(t)
 	as.StubPrompt("What merge method would you like to use?").AnswerDefault()
 	as.StubPrompt("Delete the branch locally and on GitHub?").AnswerDefault()
