@@ -3,7 +3,9 @@ package release
 import (
 	cmdCreate "github.com/cli/cli/v2/pkg/cmd/release/create"
 	cmdDelete "github.com/cli/cli/v2/pkg/cmd/release/delete"
+	cmdDeleteAsset "github.com/cli/cli/v2/pkg/cmd/release/delete-asset"
 	cmdDownload "github.com/cli/cli/v2/pkg/cmd/release/download"
+	cmdUpdate "github.com/cli/cli/v2/pkg/cmd/release/edit"
 	cmdList "github.com/cli/cli/v2/pkg/cmd/release/list"
 	cmdUpload "github.com/cli/cli/v2/pkg/cmd/release/upload"
 	cmdView "github.com/cli/cli/v2/pkg/cmd/release/view"
@@ -14,7 +16,7 @@ import (
 func NewCmdRelease(f *cmdutil.Factory) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "release <command>",
-		Short: "Manage GitHub releases",
+		Short: "Manage releases",
 		Annotations: map[string]string{
 			"IsCore": "true",
 		},
@@ -24,8 +26,10 @@ func NewCmdRelease(f *cmdutil.Factory) *cobra.Command {
 
 	cmd.AddCommand(cmdCreate.NewCmdCreate(f, nil))
 	cmd.AddCommand(cmdDelete.NewCmdDelete(f, nil))
+	cmd.AddCommand(cmdDeleteAsset.NewCmdDeleteAsset(f, nil))
 	cmd.AddCommand(cmdDownload.NewCmdDownload(f, nil))
 	cmd.AddCommand(cmdList.NewCmdList(f, nil))
+	cmd.AddCommand(cmdUpdate.NewCmdEdit(f, nil))
 	cmd.AddCommand(cmdView.NewCmdView(f, nil))
 	cmd.AddCommand(cmdUpload.NewCmdUpload(f, nil))
 
