@@ -6,45 +6,51 @@ import (
 	"net/http"
 	"os/exec"
 	"path/filepath"
-	"regexp"
 	"strings"
 
-	"github.com/AlecAivazis/survey/v2"
 	"github.com/MakeNowJust/heredoc"
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/git"
 	"github.com/cli/cli/v2/internal/config"
 	"github.com/cli/cli/v2/internal/ghrepo"
-	"github.com/cli/cli/v2/internal/run"
+	"github.com/cli/cli/v2/pkg/cmd/repo/shared"
 	"github.com/cli/cli/v2/pkg/cmdutil"
 	"github.com/cli/cli/v2/pkg/iostreams"
-	"github.com/cli/cli/v2/pkg/prompt"
 	"github.com/spf13/cobra"
 )
 
+type iprompter interface {
+	Input(string, string) (string, error)
+	Select(string, string, []string) (int, error)
+	Confirm(string, bool) (bool, error)
+}
+
 type CreateOptions struct {
 	HttpClient func() (*http.Client, error)
 	Config     func() (config.Config, error)
 	IO         *iostreams.IOStreams
+	Prompter   iprompter
 
-	Name              string
-	Description       string
-	Homepage          string
-	Team              string
-	Template          string
-	Public            bool
-	Private           bool
-	Internal          bool
-	Visibility        string
-	Push              bool
-	Clone             bool
-	Source            string
-	Remote            string
-	GitIgnoreTemplate string
-	LicenseTemplate   string
-	DisableIssues     bool
-	DisableWiki       bool
-	Interactive       bool
+	Name               string
+	Description        string
+	Homepage           string
+	Team               string
+	Template           string
+	Public             bool
+	Private            bool
+	Internal           bool
+	Visibility         string
+	Push               bool
+	Clone              bool
+	Source             string
+	Remote             string
+	GitIgnoreTemplate  string
+	LicenseTemplate    string
+	DisableIssues      bool
+	DisableWiki        bool
+	Interactive        bool
+	IncludeAllBranches bool
+	AddReadme          bool
 }
 
 func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Command {
@@ -52,6 +58,7 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 		IO:         f.IOStreams,
 		HttpClient: f.HttpClient,
 		Config:     f.Config,
+		Prompter:   f.Prompter,
 	}
 
 	var enableIssues bool
@@ -68,12 +75,12 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 			To create a remote repository non-interactively, supply the repository name and one of %[1]s--public%[1]s, %[1]s--private%[1]s, or %[1]s--internal%[1]s.
 			Pass %[1]s--clone%[1]s to clone the new repository locally.
 
-			To create a remote repository from an existing local repository, specify the source directory with %[1]s--source%[1]s. 
-			By default, the remote repository name will be the name of the source directory. 
+			To create a remote repository from an existing local repository, specify the source directory with %[1]s--source%[1]s.
+			By default, the remote repository name will be the name of the source directory.
 			Pass %[1]s--push%[1]s to push any local commits to the new repository.
 		`, "`"),
 		Example: heredoc.Doc(`
-			# create a repository interactively 
+			# create a repository interactively
 			gh repo create
 
 			# create a new remote repository and clone it locally
@@ -82,7 +89,8 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 			# create a remote repository from the current directory
 			gh repo create my-project --private --source=. --remote=upstream
 		`),
-		Args: cobra.MaximumNArgs(1),
+		Args:    cobra.MaximumNArgs(1),
+		Aliases: []string{"new"},
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if len(args) > 0 {
 				opts.Name = args[0]
@@ -133,6 +141,10 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 				return cmdutil.FlagErrorf(".gitignore and license templates are not added when template is provided")
 			}
 
+			if opts.Template != "" && opts.AddReadme {
+				return cmdutil.FlagErrorf("the `--add-readme` option is not supported with `--template`")
+			}
+
 			if cmd.Flags().Changed("enable-issues") {
 				opts.DisableIssues = !enableIssues
 			}
@@ -143,6 +155,10 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 				return cmdutil.FlagErrorf("the `--template` option is not supported with `--homepage`, `--team`, `--disable-issues`, or `--disable-wiki`")
 			}
 
+			if opts.Template == "" && opts.IncludeAllBranches {
+				return cmdutil.FlagErrorf("the `--include-all-branches` option is only supported when using `--template`")
+			}
+
 			if runF != nil {
 				return runF(opts)
 			}
@@ -165,6 +181,8 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 	cmd.Flags().BoolVarP(&opts.Clone, "clone", "c", false, "Clone the new repository to the current directory")
 	cmd.Flags().BoolVar(&opts.DisableIssues, "disable-issues", false, "Disable issues in the new repository")
 	cmd.Flags().BoolVar(&opts.DisableWiki, "disable-wiki", false, "Disable wiki in the new repository")
+	cmd.Flags().BoolVar(&opts.IncludeAllBranches, "include-all-branches", false, "Include all branches from template repository")
+	cmd.Flags().BoolVar(&opts.AddReadme, "add-readme", false, "Add a README file to the new repository")
 
 	// deprecated flags
 	cmd.Flags().BoolP("confirm", "y", false, "Skip the confirmation prompt")
@@ -184,10 +202,7 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 		if err != nil {
 			return nil, cobra.ShellCompDirectiveError
 		}
-		hostname, err := cfg.DefaultHost()
-		if err != nil {
-			return nil, cobra.ShellCompDirectiveError
-		}
+		hostname, _ := cfg.DefaultHost()
 		results, err := listGitIgnoreTemplates(httpClient, hostname)
 		if err != nil {
 			return nil, cobra.ShellCompDirectiveError
@@ -204,10 +219,7 @@ func NewCmdCreate(f *cmdutil.Factory, runF func(*CreateOptions) error) *cobra.Co
 		if err != nil {
 			return nil, cobra.ShellCompDirectiveError
 		}
-		hostname, err := cfg.DefaultHost()
-		if err != nil {
-			return nil, cobra.ShellCompDirectiveError
-		}
+		hostname, _ := cfg.DefaultHost()
 		licenses, err := listLicenseTemplates(httpClient, hostname)
 		if err != nil {
 			return nil, cobra.ShellCompDirectiveError
@@ -226,18 +238,14 @@ func createRun(opts *CreateOptions) error {
 	fromScratch := opts.Source == ""
 
 	if opts.Interactive {
-		var selectedMode string
-		modeOptions := []string{
+		selected, err := opts.Prompter.Select("What would you like to do?", "", []string{
 			"Create a new repository on GitHub from scratch",
 			"Push an existing local repository to GitHub",
-		}
-		if err := prompt.SurveyAskOne(&survey.Select{
-			Message: "What would you like to do?",
-			Options: modeOptions,
-		}, &selectedMode); err != nil {
+		})
+		if err != nil {
 			return err
 		}
-		fromScratch = selectedMode == modeOptions[0]
+		fromScratch = selected == 0
 	}
 
 	if fromScratch {
@@ -259,27 +267,35 @@ func createFromScratch(opts *CreateOptions) error {
 		return err
 	}
 
-	host, err := cfg.DefaultHost()
-	if err != nil {
-		return err
-	}
+	host, _ := cfg.DefaultHost()
 
 	if opts.Interactive {
-		opts.Name, opts.Description, opts.Visibility, err = interactiveRepoInfo("")
+		opts.Name, opts.Description, opts.Visibility, err = interactiveRepoInfo(opts.Prompter, "")
 		if err != nil {
 			return err
 		}
-		opts.GitIgnoreTemplate, err = interactiveGitIgnore(httpClient, host)
+		opts.AddReadme, err = opts.Prompter.Confirm("Would you like to add a README file?", false)
 		if err != nil {
 			return err
 		}
-		opts.LicenseTemplate, err = interactiveLicense(httpClient, host)
+		opts.GitIgnoreTemplate, err = interactiveGitIgnore(httpClient, host, opts.Prompter)
+		if err != nil {
+			return err
+		}
+		opts.LicenseTemplate, err = interactiveLicense(httpClient, host, opts.Prompter)
 		if err != nil {
 			return err
 		}
 
-		if err := confirmSubmission(opts.Name, opts.Visibility); err != nil {
+		targetRepo := shared.NormalizeRepoName(opts.Name)
+		if idx := strings.IndexRune(targetRepo, '/'); idx > 0 {
+			targetRepo = targetRepo[0:idx+1] + shared.NormalizeRepoName(targetRepo[idx+1:])
+		}
+		confirmed, err := opts.Prompter.Confirm(fmt.Sprintf(`This will create "%s" as a %s repository on GitHub. Continue?`, targetRepo, strings.ToLower(opts.Visibility)), true)
+		if err != nil {
 			return err
+		} else if !confirmed {
+			return cmdutil.CancelError
 		}
 	}
 
@@ -294,16 +310,18 @@ func createFromScratch(opts *CreateOptions) error {
 	}
 
 	input := repoCreateInput{
-		Name:              repoToCreate.RepoName(),
-		Visibility:        opts.Visibility,
-		OwnerLogin:        repoToCreate.RepoOwner(),
-		TeamSlug:          opts.Team,
-		Description:       opts.Description,
-		HomepageURL:       opts.Homepage,
-		HasIssuesEnabled:  !opts.DisableIssues,
-		HasWikiEnabled:    !opts.DisableWiki,
-		GitIgnoreTemplate: opts.GitIgnoreTemplate,
-		LicenseTemplate:   opts.LicenseTemplate,
+		Name:               repoToCreate.RepoName(),
+		Visibility:         opts.Visibility,
+		OwnerLogin:         repoToCreate.RepoOwner(),
+		TeamSlug:           opts.Team,
+		Description:        opts.Description,
+		HomepageURL:        opts.Homepage,
+		HasIssuesEnabled:   !opts.DisableIssues,
+		HasWikiEnabled:     !opts.DisableWiki,
+		GitIgnoreTemplate:  opts.GitIgnoreTemplate,
+		LicenseTemplate:    opts.LicenseTemplate,
+		IncludeAllBranches: opts.IncludeAllBranches,
+		InitReadme:         opts.AddReadme,
 	}
 
 	var templateRepoMainBranch string
@@ -350,18 +368,15 @@ func createFromScratch(opts *CreateOptions) error {
 	}
 
 	if opts.Interactive {
-		cloneQuestion := &survey.Confirm{
-			Message: "Clone the new repository locally?",
-			Default: true,
-		}
-		err = prompt.SurveyAskOne(cloneQuestion, &opts.Clone)
+		var err error
+		opts.Clone, err = opts.Prompter.Confirm("Clone the new repository locally?", true)
 		if err != nil {
 			return err
 		}
 	}
 
 	if opts.Clone {
-		protocol, err := cfg.Get(repo.RepoHost(), "git_protocol")
+		protocol, err := cfg.GetOrDefault(repo.RepoHost(), "git_protocol")
 		if err != nil {
 			return err
 		}
@@ -401,13 +416,11 @@ func createFromLocal(opts *CreateOptions) error {
 	if err != nil {
 		return err
 	}
-	host, err := cfg.DefaultHost()
-	if err != nil {
-		return err
-	}
+	host, _ := cfg.DefaultHost()
 
 	if opts.Interactive {
-		opts.Source, err = interactiveSource()
+		var err error
+		opts.Source, err = opts.Prompter.Input("Path to local repository", ".")
 		if err != nil {
 			return err
 		}
@@ -433,9 +446,9 @@ func createFromLocal(opts *CreateOptions) error {
 	}
 	if !isRepo {
 		if repoPath == "." {
-			return fmt.Errorf("current directory is not a git repository. Run `git init` to initalize it")
+			return fmt.Errorf("current directory is not a git repository. Run `git init` to initialize it")
 		}
-		return fmt.Errorf("%s is not a git repository. Run `git -C %s init` to initialize it", absPath, repoPath)
+		return fmt.Errorf("%s is not a git repository. Run `git -C \"%s\" init` to initialize it", absPath, repoPath)
 	}
 
 	committed, err := hasCommits(repoPath)
@@ -450,7 +463,7 @@ func createFromLocal(opts *CreateOptions) error {
 	}
 
 	if opts.Interactive {
-		opts.Name, opts.Description, opts.Visibility, err = interactiveRepoInfo(filepath.Base(absPath))
+		opts.Name, opts.Description, opts.Visibility, err = interactiveRepoInfo(opts.Prompter, filepath.Base(absPath))
 		if err != nil {
 			return err
 		}
@@ -498,7 +511,7 @@ func createFromLocal(opts *CreateOptions) error {
 		fmt.Fprintln(stdout, repo.URL)
 	}
 
-	protocol, err := cfg.Get(repo.RepoHost(), "git_protocol")
+	protocol, err := cfg.GetOrDefault(repo.RepoHost(), "git_protocol")
 	if err != nil {
 		return err
 	}
@@ -506,25 +519,15 @@ func createFromLocal(opts *CreateOptions) error {
 	remoteURL := ghrepo.FormatRemoteURL(repo, protocol)
 
 	if opts.Interactive {
-		var addRemote bool
-		remoteQuesiton := &survey.Confirm{
-			Message: `Add a remote?`,
-			Default: true,
-		}
-		err = prompt.SurveyAskOne(remoteQuesiton, &addRemote)
+		addRemote, err := opts.Prompter.Confirm("Add a remote?", true)
 		if err != nil {
 			return err
 		}
-
 		if !addRemote {
 			return nil
 		}
 
-		pushQuestion := &survey.Input{
-			Message: "What should the new remote be called?",
-			Default: "origin",
-		}
-		err = prompt.SurveyAskOne(pushQuestion, &baseRemote)
+		baseRemote, err = opts.Prompter.Input("What should the new remote be called?", "origin")
 		if err != nil {
 			return err
 		}
@@ -534,13 +537,10 @@ func createFromLocal(opts *CreateOptions) error {
 		return err
 	}
 
-	// don't prompt for push if there's no commits
+	// don't prompt for push if there are no commits
 	if opts.Interactive && committed {
-		pushQuestion := &survey.Confirm{
-			Message: fmt.Sprintf(`Would you like to push commits from the current branch to the %q?`, baseRemote),
-			Default: true,
-		}
-		err = prompt.SurveyAskOne(pushQuestion, &opts.Push)
+		var err error
+		opts.Push, err = opts.Prompter.Confirm(fmt.Sprintf("Would you like to push commits from the current branch to %q?", baseRemote), true)
 		if err != nil {
 			return err
 		}
@@ -551,7 +551,7 @@ func createFromLocal(opts *CreateOptions) error {
 		if err != nil {
 			return err
 		}
-		err = run.PrepareCmd(repoPush).Run()
+		err = repoPush.Run()
 		if err != nil {
 			return err
 		}
@@ -573,7 +573,7 @@ func sourceInit(io *iostreams.IOStreams, remoteURL, baseRemote, repoPath string)
 		return err
 	}
 
-	err = run.PrepareCmd(remoteAdd).Run()
+	err = remoteAdd.Run()
 	if err != nil {
 		return fmt.Errorf("%s Unable to add remote %q", cs.FailureIcon(), baseRemote)
 	}
@@ -583,14 +583,13 @@ func sourceInit(io *iostreams.IOStreams, remoteURL, baseRemote, repoPath string)
 	return nil
 }
 
-// check if local repository has commited changes
+// check if local repository has committed changes
 func hasCommits(repoPath string) (bool, error) {
 	hasCommitsCmd, err := git.GitCommand("-C", repoPath, "rev-parse", "HEAD")
 	if err != nil {
 		return false, err
 	}
-	prepareCmd := run.PrepareCmd(hasCommitsCmd)
-	err = prepareCmd.Run()
+	err = hasCommitsCmd.Run()
 	if err == nil {
 		return true, nil
 	}
@@ -635,7 +634,7 @@ func localInit(io *iostreams.IOStreams, remoteURL, path, checkoutBranch string)
 		gitInit.Stdout = io.Out
 	}
 	gitInit.Stderr = io.ErrOut
-	err = run.PrepareCmd(gitInit).Run()
+	err = gitInit.Run()
 	if err != nil {
 		return err
 	}
@@ -646,7 +645,7 @@ func localInit(io *iostreams.IOStreams, remoteURL, path, checkoutBranch string)
 	}
 	gitRemoteAdd.Stdout = io.Out
 	gitRemoteAdd.Stderr = io.ErrOut
-	err = run.PrepareCmd(gitRemoteAdd).Run()
+	err = gitRemoteAdd.Run()
 	if err != nil {
 		return err
 	}
@@ -661,7 +660,7 @@ func localInit(io *iostreams.IOStreams, remoteURL, path, checkoutBranch string)
 	}
 	gitFetch.Stdout = io.Out
 	gitFetch.Stderr = io.ErrOut
-	err = run.PrepareCmd(gitFetch).Run()
+	err = gitFetch.Run()
 	if err != nil {
 		return err
 	}
@@ -672,178 +671,68 @@ func localInit(io *iostreams.IOStreams, remoteURL, path, checkoutBranch string)
 	}
 	gitCheckout.Stdout = io.Out
 	gitCheckout.Stderr = io.ErrOut
-	return run.PrepareCmd(gitCheckout).Run()
+	return gitCheckout.Run()
 }
 
-func interactiveGitIgnore(client *http.Client, hostname string) (string, error) {
-	var addGitIgnore bool
-	var addGitIgnoreSurvey []*survey.Question
-
-	addGitIgnoreQuestion := &survey.Question{
-		Name: "addGitIgnore",
-		Prompt: &survey.Confirm{
-			Message: "Would you like to add a .gitignore?",
-			Default: false,
-		},
+func interactiveGitIgnore(client *http.Client, hostname string, prompter iprompter) (string, error) {
+	confirmed, err := prompter.Confirm("Would you like to add a .gitignore?", false)
+	if err != nil {
+		return "", err
+	} else if !confirmed {
+		return "", nil
 	}
 
-	addGitIgnoreSurvey = append(addGitIgnoreSurvey, addGitIgnoreQuestion)
-	err := prompt.SurveyAsk(addGitIgnoreSurvey, &addGitIgnore)
+	templates, err := listGitIgnoreTemplates(client, hostname)
 	if err != nil {
 		return "", err
 	}
-
-	var wantedIgnoreTemplate string
-
-	if addGitIgnore {
-		var gitIg []*survey.Question
-
-		gitIgnoretemplates, err := listGitIgnoreTemplates(client, hostname)
-		if err != nil {
-			return "", err
-		}
-		gitIgnoreQuestion := &survey.Question{
-			Name: "chooseGitIgnore",
-			Prompt: &survey.Select{
-				Message: "Choose a .gitignore template",
-				Options: gitIgnoretemplates,
-			},
-		}
-		gitIg = append(gitIg, gitIgnoreQuestion)
-		err = prompt.SurveyAsk(gitIg, &wantedIgnoreTemplate)
-		if err != nil {
-			return "", err
-		}
-
-	}
-
-	return wantedIgnoreTemplate, nil
-}
-
-func interactiveLicense(client *http.Client, hostname string) (string, error) {
-	var addLicense bool
-	var addLicenseSurvey []*survey.Question
-	var wantedLicense string
-
-	addLicenseQuestion := &survey.Question{
-		Name: "addLicense",
-		Prompt: &survey.Confirm{
-			Message: "Would you like to add a license?",
-			Default: false,
-		},
-	}
-
-	addLicenseSurvey = append(addLicenseSurvey, addLicenseQuestion)
-	err := prompt.SurveyAsk(addLicenseSurvey, &addLicense)
+	selected, err := prompter.Select("Choose a .gitignore template", "", templates)
 	if err != nil {
 		return "", err
 	}
+	return templates[selected], nil
+}
 
-	licenseKey := map[string]string{}
-
-	if addLicense {
-		licenseTemplates, err := listLicenseTemplates(client, hostname)
-		if err != nil {
-			return "", err
-		}
-		var licenseNames []string
-		for _, l := range licenseTemplates {
-			licenseNames = append(licenseNames, l.Name)
-			licenseKey[l.Name] = l.Key
-		}
-		var licenseQs []*survey.Question
-
-		licenseQuestion := &survey.Question{
-			Name: "chooseLicense",
-			Prompt: &survey.Select{
-				Message: "Choose a license",
-				Options: licenseNames,
-			},
-		}
-		licenseQs = append(licenseQs, licenseQuestion)
-		err = prompt.SurveyAsk(licenseQs, &wantedLicense)
-		if err != nil {
-			return "", err
-		}
-		return licenseKey[wantedLicense], nil
+func interactiveLicense(client *http.Client, hostname string, prompter iprompter) (string, error) {
+	confirmed, err := prompter.Confirm("Would you like to add a license?", false)
+	if err != nil {
+		return "", err
+	} else if !confirmed {
+		return "", nil
 	}
-	return "", nil
+
+	licenses, err := listLicenseTemplates(client, hostname)
+	if err != nil {
+		return "", err
+	}
+	licenseNames := make([]string, 0, len(licenses))
+	for _, license := range licenses {
+		licenseNames = append(licenseNames, license.Name)
+	}
+	selected, err := prompter.Select("Choose a license", "", licenseNames)
+	if err != nil {
+		return "", err
+	}
+	return licenses[selected].Key, nil
 }
 
 // name, description, and visibility
-func interactiveRepoInfo(defaultName string) (string, string, string, error) {
-	qs := []*survey.Question{
-		{
-			Name: "repoName",
-			Prompt: &survey.Input{
-				Message: "Repository name",
-				Default: defaultName,
-			},
-		},
-		{
-			Name:   "repoDescription",
-			Prompt: &survey.Input{Message: "Description"},
-		},
-		{
-			Name: "repoVisibility",
-			Prompt: &survey.Select{
-				Message: "Visibility",
-				Options: []string{"Public", "Private", "Internal"},
-			},
-		}}
-
-	answer := struct {
-		RepoName        string
-		RepoDescription string
-		RepoVisibility  string
-	}{}
-
-	err := prompt.SurveyAsk(qs, &answer)
+func interactiveRepoInfo(prompter iprompter, defaultName string) (string, string, string, error) {
+	name, err := prompter.Input("Repository name", defaultName)
 	if err != nil {
 		return "", "", "", err
 	}
 
-	return answer.RepoName, answer.RepoDescription, strings.ToUpper(answer.RepoVisibility), nil
-}
-
-func interactiveSource() (string, error) {
-	var sourcePath string
-	sourcePrompt := &survey.Input{
-		Message: "Path to local repository",
-		Default: "."}
-
-	err := prompt.SurveyAskOne(sourcePrompt, &sourcePath)
+	description, err := prompter.Input("Description", defaultName)
 	if err != nil {
-		return "", err
+		return "", "", "", err
 	}
-	return sourcePath, nil
-}
 
-func confirmSubmission(repoWithOwner, visibility string) error {
-	targetRepo := normalizeRepoName(repoWithOwner)
-	if idx := strings.IndexRune(repoWithOwner, '/'); idx > 0 {
-		targetRepo = repoWithOwner[0:idx+1] + normalizeRepoName(repoWithOwner[idx+1:])
-	}
-	var answer struct {
-		ConfirmSubmit bool
-	}
-	err := prompt.SurveyAsk([]*survey.Question{{
-		Name: "confirmSubmit",
-		Prompt: &survey.Confirm{
-			Message: fmt.Sprintf(`This will create "%s" as a %s repository on GitHub. Continue?`, targetRepo, strings.ToLower(visibility)),
-			Default: true,
-		},
-	}}, &answer)
+	visibilityOptions := []string{"Public", "Private", "Internal"}
+	selected, err := prompter.Select("Visibility", "Public", visibilityOptions)
 	if err != nil {
-		return err
+		return "", "", "", err
 	}
-	if !answer.ConfirmSubmit {
-		return cmdutil.CancelError
-	}
-	return nil
-}
 
-// normalizeRepoName takes in the repo name the user inputted and normalizes it using the same logic as GitHub (GitHub.com/new)
-func normalizeRepoName(repoName string) string {
-	return strings.TrimSuffix(regexp.MustCompile(`[^\w._-]+`).ReplaceAllString(repoName, "-"), ".git")
+	return name, description, strings.ToUpper(visibilityOptions[selected]), nil
 }
