@@ -399,6 +399,30 @@ func TestSessionHeartbeat(t *testing.T) {
 	}
 }
 
+func TestRebuild(t *testing.T) {
+	requestCount := 0
+	getSharedServers := func(conn *jsonrpc2.Conn, req *jsonrpc2.Request) (interface{}, error) {
+		requestCount++
+		return true, nil
+	}
+	testServer, session, err := makeMockSession(
+		livesharetest.WithService("IEnvironmentConfigurationService.rebuildContainer", getSharedServers),
+	)
+	if err != nil {
+		t.Fatalf("creating mock session: %v", err)
+	}
+	defer testServer.Close()
+
+	err = session.RebuildContainer(context.Background())
+	if err != nil {
+		t.Fatalf("rebuilding codespace via mock session: %v", err)
+	}
+
+	if requestCount == 0 {
+		t.Fatalf("no requests were made")
+	}
+}
+
 type mockLogger struct {
 	sync.Mutex
 	buf *bytes.Buffer
